<template>
  <div>
    <!--表格基础按钮-->
    <div v-if="type === 'table'">
      <!--top展示表格上方区域 menu展示表格操作栏区域 -->
      <el-button v-for="item in basicButtonList.top"
                 v-if="LocationType === 'top'"
                 :key="item.oid" :icon="item.paramVOS.webUiButtonIcon"
                 :type="item.paramVOS.webUiButtonType || 'primary'" plain
                 size="small"
                 @click="buttonClick(item)">
        {{ item.name }}
      </el-button>

      <el-button v-for="item in basicButtonList.menu"
                 v-if="LocationType === 'menu'"
                 :key="item.oid"
                 :icon="item.paramVOS.webUiButtonIcon ? item.paramVOS.webUiButtonIcon : (item.paramVOS.webUiButtonMethods === 'edit' ? 'el-icon-edit' : (item.paramVOS.webUiButtonMethods === 'delete' ? 'el-icon-delete' : ''))"
                 :type="item.paramVOS.webUiButtonType || 'text'" plain
                 size="small"
                 @click="buttonClick(item)">
        {{ item.name }}
      </el-button>
      <!-- 表格内按钮操作对话框表单   -->
      <dynamic-table-form ref="dynamicForm" :formList="formList" :title="formName" :visible.sync="visible"
                          style="display: none"></dynamic-table-form>
    </div>
    <div v-else-if="type === 'form'">
      <el-button v-for="item in basicButtonList"
                 :key="item.oid"
                 :icon="item.paramVOS.webUiButtonIcon"
                 :type="(item.paramVOS.webUiButtonType !== 'text' ? item.paramVOS.webUiButtonType : 'primary') || 'primary'"
                 plain
                 size="small"
                 @click="buttonClick(item)">
        {{ item.name }}
      </el-button>
    </div>
  </div>
</template>

<script>
import func from "@/util/func";
import {validatenull} from "@/util/validate";

export default {
  name: "dynamic-button",
  props: {
    type: {
      type: String
    },
    LocationType: {
      type: String,
    },
    scope: {
      type: Object,
    },
    butttonList: {
      type: Array
    },
    selectList: {
      type: Array
    }
  },
  data() {
    return {
      visible: false,
      formName: '',
      // 表单数据
      formList: [
        {
          comboxKey: null,
          customClass: null,
          data: null,
          dateFormate: null,
          defaultValue: "",
          displayExtension: "",
          extendAttrMap: null,
          extendAttrString: null,
          field: "name",
          hidden: false,
          keyAttr: true,
          prefix: null,
          readOnly: false,
          referConfig: null,
          required: true,
          selectLibFlag: null,
          showField: null,
          suffix: '$',
          text: "名称",
          tooltips: '名称',
          type: "text",
          unique: false,
          verify: ""
        },
        {
          comboxKey: null,
          customClass: null,
          data: null,
          dateFormate: null,
          defaultValue: "",
          displayExtension: "",
          extendAttrMap: null,
          extendAttrString: null,
          field: "code",
          hidden: false,
          keyAttr: false,
          prefix: null,
          readOnly: false,
          referConfig: null,
          required: false,
          selectLibFlag: null,
          showField: null,
          suffix: null,
          disabled: true,
          text: "编码",
          tooltips: null,
          type: "text",
          unique: false,
          verify: ""
        },
        {
          comboxKey: "EnumReviewType",
          customClass: null,
          data: null,
          dateFormate: null,
          defaultValue: "department",
          displayExtension: "",
          extendAttrMap: null,
          extendAttrString: null,
          field: "reviewtype",
          hidden: false,
          keyAttr: false,
          prefix: null,
          readOnly: false,
          referConfig: null,
          required: false,
          selectLibFlag: null,
          showField: null,
          suffix: null,
          text: "类型",
          tooltips: null,
          type: "combox",
          unique: false,
          verify: "",
          dicData: [{
            label: '测试1',
            value: 'department'
          }, {
            label: '测试2',
            value: 'departments'
          }]
        },
        {
          comboxKey: null,
          customClass: null,
          data: null,
          dateFormate: null,
          defaultValue: "",
          displayExtension: "",
          extendAttrMap: null,
          extendAttrString: null,
          field: "creator",
          hidden: true,
          keyAttr: false,
          prefix: null,
          readOnly: true,
          referConfig: null,
          required: false,
          selectLibFlag: null,
          showField: null,
          suffix: null,
          text: "创建人",
          tooltips: null,
          type: "text",
          unique: false,
          verify: ""
        },
        {
          comboxKey: null,
          customClass: null,
          data: null,
          dateFormate: "yyyy-MM-dd HH:mm:ss",
          defaultValue: "",
          displayExtension: "",
          extendAttrMap: null,
          extendAttrString: null,
          field: "createtime",
          hidden: true,
          keyAttr: false,
          prefix: null,
          readOnly: false,
          referConfig: null,
          required: false,
          selectLibFlag: null,
          showField: null,
          suffix: null,
          text: "创建时间",
          tooltips: null,
          type: "datetime",
          unique: false,
          verify: ""
        },
        {
          comboxKey: null,
          customClass: null,
          data: null,
          dateFormate: null,
          defaultValue: "",
          displayExtension: "",
          extendAttrMap: null,
          extendAttrString: null,
          field: "content",
          hidden: false,
          keyAttr: false,
          prefix: null,
          readOnly: false,
          referConfig: null,
          required: false,
          selectLibFlag: null,
          showField: null,
          suffix: null,
          text: "备注",
          tooltips: null,
          type: "textarea",
          unique: false,
          verify: ""
        },
      ],
    }
  },
  computed: {
    basicButtonList() {
      const basicColumn = this.butttonList;

      if (this.type === 'form') {
        return basicColumn;
      } else if (this.type === 'table') {
        const top = basicColumn.filter(item => item.paramVOS.webUiButtonLocation === 'top' || func.isEmpty(item.paramVOS.webUiButtonLocation)); // 过滤出来表格上面区域展示的按钮
        const menu = basicColumn.filter(item => item.paramVOS.webUiButtonLocation === 'menu'); // 过滤出来操作栏展示的按钮

        return {
          top: top,
          menu: menu
        };
      }
    }
  },
  methods: {
    buttonClick(item) {
      this.formName = item.name;

      function handleAdd() {
        this.visible = true;
      }

      function handleEdit() {
        const location = item.paramVOS.webUiButtonLocation;
        if (location === 'menu') {
          this.visible = true;
          this.$refs.dynamicForm.form = this.scope.row;
        } else if (location === 'top' && this.selectList.length === 1) {
          this.visible = true;
          this.$refs.dynamicForm.form = this.selectList[0];
        } else {
          const messageText = this.selectList.length > 1 ? '只能选择一条数据进行编辑！' : '请选择一条数据进行编辑！';
          this.$message.warning(messageText);
        }
      }

      function handleDelete() {
        const location = item.paramVOS.webUiButtonLocation;
        if (location === 'top') {
          if (this.selectList.length <= 0) {
            this.$message.warning('请至少选择一条数据！')
          } else {
            this.$message.success('删除成功！');
          }
        } else if (location === 'menu') {
          this.$message.success('删除成功！');
        }
      }

      const methodHandlers = {
        add: handleAdd.bind(this),
        edit: handleEdit.bind(this),
        delete: handleDelete.bind(this),
      };

      const method = item.paramVOS.webUiButtonMethods;
      const handler = methodHandlers[method];
      if (handler) {
        handler();
      } else {
        this.$message.error('请重新配置按钮！')
      }
    }
  }
}
</script>

<style scoped>

</style>
